==> qmmp_0.2.3.orig.tar.gz: qmmp-0.2.3/src/plugins/General/notifier/translations/notifier_plugin_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="cs">
<context>
    <name>NotifierFactory</name>
    <message>
        <location filename="../notifierfactory.cpp" line="30"/>
        <source>Notifier Plugin</source>
        <translation>Notifikační modul</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="49"/>
        <source>About Notifier Plugin</source>
        <translation>O notifikačním modulu</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="50"/>
        <source>Qmmp Notifier Plugin</source>
        <translation>Notifikační modul Qmmp</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="51"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilja Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="13"/>
        <source>Notifier Plugin Settings</source>
        <translation>Nastavení notifikačního modulu</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="19"/>
        <source>Psi Notification</source>
        <translation>Notifikace v Psi</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="25"/>
        <source>Enable Psi notification</source>
        <translation>Povolit notifikaci v Psi</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="35"/>
        <source>Desktop Notification</source>
        <translation>Notifikace na pracovní ploše</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="41"/>
        <source>Enable desktop notification</source>
        <translation>Povolit notifikaci na pracovní ploše</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="48"/>
        <source>Message delay, ms:</source>
        <translation>Prodleva zprávy, ms:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="74"/>
        <source>Position</source>
        <translation>Umístění</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="248"/>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="255"/>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
</context>
</TS>

==> qmmp_0.3.1.orig.tar.gz: qmmp-0.3.1/src/plugins/General/notifier/translations/notifier_plugin_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="cs">
<context>
    <name>NotifierFactory</name>
    <message>
        <location filename="../notifierfactory.cpp" line="30"/>
        <source>Notifier Plugin</source>
        <translation>Notifikační modul</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="50"/>
        <source>About Notifier Plugin</source>
        <translation>O notifikačním modulu</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="51"/>
        <source>Qmmp Notifier Plugin</source>
        <translation>Notifikační modul Qmmp</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="52"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Autor: Ilja Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>PopupWidget</name>
    <message>
        <location filename="../popupwidget.cpp" line="115"/>
        <source>Volume:</source>
        <translation>Hlasitost:</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="13"/>
        <source>Notifier Plugin Settings</source>
        <translation>Nastavení notifikačního modulu</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="19"/>
        <source>Psi Notification</source>
        <translation>Notifikace v Psi</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="25"/>
        <source>Enable Psi notification</source>
        <translation>Povolit notifikaci v Psi</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="35"/>
        <source>Desktop Notification</source>
        <translation>Notifikace na pracovní ploše</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="248"/>
        <source>Position</source>
        <translation>Umístění</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="41"/>
        <source>Song change notification</source>
        <translation>Upozornění na změnu skladby</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="48"/>
        <source>Volume change notification</source>
        <translation>Upozornění na změnu hlasitosti</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Delay, ms:</source>
        <translation>Prodleva v ms:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="81"/>
        <source>Transparency</source>
        <translation>Průhlednost</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="104"/>
        <source>0</source>
        <translation>0</translation>
    </message>
</context>
</TS>
